Search.setIndex({desctypes:{"0":"function"},terms:{code:0,lack:0,abil:[],follow:0,alt:0,depend:[],articl:0,program:0,under:0,sens:0,sourc:0,string:0,fals:0,veri:0,list:0,defens:0,"try":0,quick:0,work:0,pass:0,download:0,odd:0,port:[],longstand:0,index:0,what:0,compar:[],abl:[],current:0,version:0,ampersand:0,net:0,boost:0,full:0,abov:[],gener:0,here:0,bodi:0,path:0,modifi:0,valu:0,convert:0,implement:0,portabl:[],transit:0,apt:0,"boolean":0,instal:0,from:0,describ:0,memori:0,two:0,few:[],call:0,checkout:0,more:0,unescap:0,ctype:[],enhanc:[],warn:0,must:0,none:0,word:0,setup:[],outlin:0,can:0,purpos:0,fragment:0,share:0,tag:0,unreli:0,alwai:0,end:0,write:[],how:0,instead:0,xhtml:0,config:0,after:0,date:[],"short":0,element:0,inform:0,maintain:[],int64:0,allow:0,tidy_docu:0,order:0,help:0,through:0,vari:[],cvsroot:0,entiti:0,snippet:0,img:0,chosen:0,fix:0,better:0,platform:0,window:0,tidylib:0,might:0,them:0,"return":0,thei:0,python:0,discuss:0,name:0,anyth:0,fulli:[],unicod:0,compil:[],replac:0,libtidi:0,wrap:0,meta:0,expect:0,out:0,unclos:0,open:0,content:0,print:0,correct:0,free:[],small:0,releas:0,org:0,indent:0,thread:0,turn:[],place:0,outsid:0,first:0,softwar:0,directli:0,onc:0,clariti:0,number:0,yourself:[],mai:0,instruct:0,alreadi:0,least:0,dylib:0,miss:0,convent:0,system:0,messag:0,too:0,statement:[],termin:0,store:0,option:0,especi:0,tool:0,setuptool:0,prebuilt:0,provid:0,charact:0,project:0,str:0,were:0,pre:0,argument:0,packag:0,have:0,tidi:0,built:0,lib:0,note:0,also:0,without:0,build:0,which:0,distribut:0,normal:0,object:0,utidylib:0,bsd:0,homepag:[],don:0,doc:0,later:0,doe:[],yum:0,clean:0,latest:0,text:0,trivial:[],find:[],xml:0,onli:0,locat:0,execut:0,pretti:0,configur:0,should:0,dict:0,various:0,meant:0,hit:0,get:0,between:0,report:[],pserver:0,cstringio:[],bar:0,release_tidy_doc:0,patch:0,set:0,see:0,result:0,best:[],someth:0,dll:0,written:0,outstand:[],computerhop:0,"import":0,numer:0,entir:0,html4:0,extent:0,both:0,against:0,etc:0,improv:0,com:0,linux:0,desktop:[],overlook:0,due:[],empti:0,insenst:0,much:0,tidy_frag:0,ani:0,present:0,"case":0,vanilla:0,sourceforg:0,"while":[],behavior:0,error:0,anonym:0,site:0,jpg:0,keep_doc:0,sever:0,develop:0,author:0,perform:0,make:0,binari:0,html:0,decod:0,document:0,complet:0,base_opt:0,capabl:0,user:0,mani:0,appropri:[],markup:0,well:0,exampl:0,command:0,thi:0,usual:0,just:0,rest:0,speed:0,previous:0,web:0,littl:0,complain:0,add:0,valid:0,modul:0,read:0,bit:0,like:0,semi:[],server:0,output:0,manag:0,some:0,back:0,proper:0,home:[],librari:0,affili:0,bottom:0,leak:0,per:0,larg:0,refer:0,run:0,slight:0,found:0,src:0,about:0,actual:0,page:0,produc:0,own:[],encod:0,easy_instal:0,been:[],strip:0,ensur:0,mark:0,your:0,wai:0,area:0,support:0,question:0,avail:0,strict:0,reli:[],appl:[],interfac:0,includ:0,"function":0,doctyp:0,repeatedli:[],forc:0,link:0,line:0,"true":0,bug:[],utf:0,consist:0,possibl:[],"default":0,below:0,otherwis:0,similar:0,pytidylib:0,certain:0,pip:0,fill:0,vista:0,titl:0,when:0,invalid:0,other:0,downlaod:[],you:0,otild:0,intend:0,stringio:[],briefli:0,directori:0,scroll:0,tidy_fraga:0},titles:["PyTidyLib: A Python Interface to HTML Tidy"],modules:{},descrefs:{tidylib:{tidy_document:[0,0],tidy_fragment:[0,0],release_tidy_doc:[0,0]}},filenames:["index"]})